@@ -1,12 +1,8 @@
 # -*- coding: utf-8 -*-
 
-"""
-Powerful and Lightweight Python Tree Data Structure.
+"""Powerful and Lightweight Python Tree Data Structure."""
 
-
-"""
-
-__version__ = "2.7.1"
+__version__ = "2.7.2"
 __author__ = "c0fec0de"
 __author_email__ = "c0fec0de@gmail.com"
 __description__ = """Powerful and Lightweight Python Tree Data Structure.."""
